const showLog = false;
let os = '';
function log() {
    showLog && console.log.apply(console, arguments);
}

// note this gets called on extension install + update, but also on chrome update.
function recordInstall(currentAppVersion, currentTime) {

    // They may have existing values. So, we request them.
    chrome.storage.sync.get({
        "appVersionHistory": [],
        "initialAppInstallTime": currentTime
    }, savedVals => {

        // Add the current version to the user's history, if not already there.
        const versions = savedVals.appVersionHistory;
        if (!versions.includes(currentAppVersion)) {
            versions.push(currentAppVersion);
        }

        // Now we write the values back, likely setting them for the first time.
        chrome.storage.sync.set({
            "appVersionHistory": versions,
            "initialAppInstallTime": savedVals.initialAppInstallTime,
            "mostRecentUpdateTime": currentTime,
        }, updateUninstallUrl);

    });
}

// max url length is 255 chars, and we hit this limit sometimes.
// So, we'll try to build the longest url we can by dropping query string args until we get under the limit.
function buildUrl(queryArgs) {
    const urlBase = 'http://rehfeld.us/browser-extensions/uninstall-survey.php?';
    const maxChars = 255 - urlBase.length;

    // Discard args towards the end first.
    while (queryArgs.join('&').length > maxChars) {
        queryArgs.pop();
    }

    return urlBase + queryArgs.join('&');
}

function updateUninstallUrl() {
    chrome.storage.sync.get(["appVersionHistory", "initialAppInstallTime", "mostRecentUpdateTime"], syncVals => {
        chrome.storage.local.get({usageStats: {}}, localVals => {
            const manifest = chrome.runtime.getManifest();
            const usageStatsQueryArgs = Object.keys(localVals.usageStats).map(key => `${encodeURIComponent(key)}=${encodeURIComponent(localVals.usageStats[key])}`);


            // To save space, we only send min and max versions.
            const versions = syncVals.appVersionHistory.sort();
            let versionRange = versions[0];
            if (versions.length > 1) {
                versionRange +=  "," + versions[versions.length - 1];
            }

            // todo, drop some stats to ensure length budget.

            // chrome imposes a 255 char url limit, so we need to use compact query var names.
            const queryArgs = [
                `app=${encodeURIComponent(manifest.extNameCode)}`,
                `it=${encodeURIComponent(syncVals.initialAppInstallTime)}`,
                `ut=${encodeURIComponent(syncVals.mostRecentUpdateTime)}`,
                `vh=${encodeURIComponent(versionRange)}`,
                // os might not yet have a value, but oh well.
                `os=${encodeURIComponent(os)}`,
                ... usageStatsQueryArgs
            ];

            // log("setUninstallURL", url);
            chrome.runtime.setUninstallURL(buildUrl(queryArgs));
        });
    });
}

chrome.runtime.onInstalled.addListener(details => {
    log("onInstall", details);
    const manifest = chrome.runtime.getManifest();
    recordInstall(manifest.version, unixTimestamp());
});

// Record the os so the content-script can access it.
chrome.runtime.getPlatformInfo(function(info) {
    os = info.os;
    chrome.storage.local.set({
        os
    }, () => {
        // console.log('set os')
    });
});

chrome.storage.onChanged.addListener(updateUninstallUrl);

// chrome.runtime.onInstalled.addListener((details) => {
//     const currentVersion = chrome.runtime.getManifest().version;
//     const previousVersion = details.previousVersion;
//     const reason = details.reason;
//
//     chrome.tabs.create({ url: chrome.runtime.getURL("ext-web/updated.html?v=" + encodeURIComponent(currentVersion)) });
//
//     if (reason === 'update') {
//
//     }
//
// })

function unixTimestamp() {
    return Math.floor(Date.now() / 1000);
}

// chrome.commands.onCommand.addListener(function(command) {
//     console.log('Command:', command);
//     // command === 'seek-backwards-short'
//
// });


// window.opt = () => {
//     chrome.runtime.openOptionsPage(function () {
//         log('openOptionsPage', arguments);
//     });
// };

